Stan Math Library: stan/math/prim/scal/fun/grad_reg_inc_gamma.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
grad_reg_inc_gamma.hpp File Reference
`#include <stan/math/prim/scal/fun/gamma_p.hpp>`
`#include <cmath>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T | stan::math::grad_reg_inc_gamma (T a, T z, T g, T dig, T precision=1e-6)

[ Stan Home Page ] © 2011–2016, Stan Development Team.